@@ -7,7 +7,7 @@ DIR=joda-time-$VERSION
 
 # clean up the upstream tarball
 tar zxvf $3
-mv joda-time-$VERSION $DIR
+rm $3
 GZIP=--best tar -czf $TAR --exclude '*.jar' $DIR
 rm -rf $DIR
 
